@@ -17,6 +17,7 @@
 #include <KPluginFactory>
 
 #include <algorithm>
+#include <KIO/OpenFileManagerWindowJob>
 
 #include "pluginmanager.h"
 #include "addtoarchive.h"
@@ -114,8 +115,10 @@ QAction *CompressFileItemAction::createAction(const QIcon &icon, QWidget *parent
             }
         }
         addToArchiveJob->start();
-        connect(addToArchiveJob, &KJob::finished, this, [this, addToArchiveJob]() {
-            if (addToArchiveJob->error() != 0) {
+        connect(addToArchiveJob, &KJob::finished, this, [this, addToArchiveJob](){
+            if (addToArchiveJob->error() == 0) {
+                KIO::highlightInFileManager({QUrl::fromLocalFile(addToArchiveJob->fileName())});
+            } else if (!addToArchiveJob->errorString().isEmpty()) {
                 Q_EMIT error(addToArchiveJob->errorString());
             }
         });
