@@ -25,7 +25,7 @@ class ArkViewer : public KParts::MainWindow, public Ui::ArkViewer
 public:
     ~ArkViewer() override;
 
-    static void view(const QString& fileName);
+    static void view(const QString& fileName, const QString& entryPath = QString());
 
 private:
     explicit ArkViewer();
@@ -34,11 +34,11 @@ private:
     static KService::Ptr getInternalViewer(const QString& mimeType);
 
     static void openExternalViewer(const KService::Ptr viewer, const QString& fileName);
-    static void openInternalViewer(const KService::Ptr viewer, const QString& fileName, const QMimeType& mimeType);
+    static void openInternalViewer(const KService::Ptr viewer, const QString& fileName, const QString& entryPath, const QMimeType& mimeType);
 
     static bool askViewAsPlainText(const QMimeType& mimeType);
 
-    bool viewInInternalViewer(const KService::Ptr viewer, const QString& fileName, const QMimeType& mimeType);
+    bool viewInInternalViewer(const KService::Ptr viewer, const QString& fileName, const QString &entryPath, const QMimeType& mimeType);
 
 private Q_SLOTS:
     void aboutKPart();
